@@ -4,7 +4,7 @@ import logging
 import os
 import sys
 
-from mendiafilescraper.Scraper import Scraper
+from mendiafilescraper.scraper import Scraper
 
 
 async def run(arguments):
@@ -17,7 +17,7 @@ async def run(arguments):
     if arguments.debug:
         logger = logging.getLogger(Scraper.__name__)
         logger.setLevel(level="DEBUG")
-        logging.debug(f"Running {__name__} with --debug")
+        logging.debug("Running %s with --debug", __name__)
 
     path = os.getcwd()
     env_path = os.environ["PATH"]
