@@ -17,7 +17,7 @@ from mendiafilescraper.mendia import Movie, get_tmdb_api_key, publish_movies
 from mendiafilescraper.path_element import FileObject, PathElement, PathObject
 
 
-class MovieScrapper:
+class MovieScraper:
     @staticmethod
     def parse_media_info(path: str):
 
@@ -136,7 +136,7 @@ class MovieScrapper:
 
     @staticmethod
     def get_media_info_file(file: Path):
-        return MovieScrapper.parse_media_info(file.absolute().as_posix())
+        return MovieScraper.parse_media_info(file.absolute().as_posix())
 
     @staticmethod
     def get_media_info_video_ts(path: Path):
@@ -149,7 +149,7 @@ class MovieScrapper:
                     resolution,
                     audio_languages,
                     subtitle_languages,
-                ) = MovieScrapper.parse_media_info(file.absolute().as_posix())
+                ) = MovieScraper.parse_media_info(file.absolute().as_posix())
                 if bitrate != -1:
                     return (
                         bitrate,
@@ -185,7 +185,7 @@ class MovieScrapper:
         tmdb.API_KEY = tmdb_api_key
         search = tmdb.Search()
 
-        title, year = MovieScrapper.get_year_and_title(filename)
+        title, year = MovieScraper.get_year_and_title(filename)
 
         def search_movie():
             if year > 0:
@@ -230,7 +230,7 @@ class MovieScrapper:
                 resolution,
                 audio_languages,
                 subtitle_languages,
-            ) = MovieScrapper.get_media_info_file(Path(file_object.absolute_file_path))
+            ) = MovieScraper.get_media_info_file(Path(file_object.absolute_file_path))
             if bitrate == -1:
                 logging.warning(
                     "The media information for %s could not be extracted",
@@ -249,7 +249,7 @@ class MovieScrapper:
                 resolution,
                 audio_languages,
                 subtitle_languages,
-            ) = MovieScrapper.get_media_info_video_ts(Path(absolute_path))
+            ) = MovieScraper.get_media_info_video_ts(Path(absolute_path))
             if bitrate is None:
                 logging.warning(
                     "The media information for the VIDEO_TS folder of %s could not be extraced",
@@ -397,7 +397,7 @@ class MovieScrapper:
                 )
 
             results: List[Union[FileObject, PathObject, None]] = pool.starmap(
-                MovieScrapper.compute_hash, objects
+                MovieScraper.compute_hash, objects
             )
 
             arguments: List[Tuple[Union[FileObject, PathObject], str]] = []
@@ -405,10 +405,10 @@ class MovieScrapper:
                 if result is None:
                     continue
                 if len(Movies.select().where(Movies.hash == result.hash_sum)) == 0:
-                    arguments.append((result,))
+                    arguments.append((result, tmdb_api_key))
 
             movies: List[Union[Movie, None]] = pool.starmap(
-                MovieScrapper.add_movie, arguments
+                MovieScraper.add_movie, arguments
             )
 
             # For publishing movies
